==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the query header to redact. This setting must be provided in lowercase characters.
 */
public data class WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs(
    public val name: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs> {
    override fun toJava():
        com.pulumi.aws.wafv2.inputs.WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs =
        com.pulumi.aws.wafv2.inputs.WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs.builder()
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs].
 */
@PulumiTagMarker
public class WebAclLoggingConfigurationRedactedFieldSingleHeaderArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value Name of the query header to redact. This setting must be provided in lowercase characters.
     */
    @JvmName("bcubbcwhkddcuhfs")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Name of the query header to redact. This setting must be provided in lowercase characters.
     */
    @JvmName("gvxobufvnnmjoioo")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs =
        WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs(
            name = name ?: throw PulumiNullFieldException("name"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the query header to redact. This setting must be provided in lowercase characters.
 */
public data class WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs(
    public val name: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs =
        com.pulumi.aws.wafv2.inputs.WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs.builder()
            .name(name.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs].
 */
@PulumiTagMarker
public class WebAclLoggingConfigurationRedactedFieldSingleHeaderArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value Name of the query header to redact. This setting must be provided in lowercase characters.
     */
    @JvmName("mfnyptwflnggwonb")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Name of the query header to redact. This setting must be provided in lowercase characters.
     */
    @JvmName("bdxqxoyrplliooyh")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs =
        WebAclLoggingConfigurationRedactedFieldSingleHeaderArgs(
            name = name ?: throw PulumiNullFieldException("name"),
        )
}
